GenuineSignWageCabinCompanion class
Constructors
-
GenuineSignWageCabinCompanion({Value<
int> scratchStaredRoarWave = const i0.Value.absent(), Value<String> makeFragrantBombMonk = const i0.Value.absent()}) -
const
-
GenuineSignWageCabinCompanion.insert({Value<
int> scratchStaredRoarWave = const i0.Value.absent(), required String makeFragrantBombMonk})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
makeFragrantBombMonk
→ Value<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scratchStaredRoarWave
→ Value<
int> -
final
Methods
-
copyWith(
{Value< int> ? scratchStaredRoarWave, Value<String> ? makeFragrantBombMonk}) → GenuineSignWageCabinCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
custom(
{Expression< int> ? scratchStaredRoarWave, Expression<String> ? makeFragrantBombMonk}) → Insertable<GenuineSignWageCabinEntity>